'use strict';
const requestPromise = require("request-promise");

const apiHost = 'https://api.worldweatheronline.com/premium/v1/weather.ashx';
const apiKey = '----------Your API Key----------'; /* Your API key */
const format = 'json';
const timePeriod = '1';
const numsOfDay = '1';
const forecastIn24Hour = 'no';
const includeLocation = 'no';
const monthlyCalculation = 'no';
const forecast = 'no';
const currentCondition = 'yes';
const showMapUrl = 'no';
let latitude = '';
let longitude = '';
exports.handler = async event => {

  if (event.call === 'lambda') {
    console.log('CALLED:LAMBDA');

    /**
     * 空コール時に外部モジュールをキャッシュする
     * ex : if ( xxxx !== null ){} // xxxx : 生成したインスタンス
     */
    if (requestPromise !== null) { }
    return;
  }

  console.log('Thermometer Request:', JSON.stringify(event));

  const useCurrentLocation = event.properties.preferences.useCurrentLocation;

  if (useCurrentLocation) {
    latitude = event.properties.parameters.location.latitude;
    longitude = event.properties.parameters.location.longitude;
  } else {
    const prefMap = event.properties.preferences.prefMap;
    latitude = prefMap[0];
    longitude = prefMap[1];
  }

  let response = {
    status: 200,
    body: { temperature: 59 }
  };

  try {
    if (latitude === undefined || longitude === undefined) {
      throw Error('Location information is missing');
    }

    const data = await requestPromise({
      method: 'GET',
      uri: `${apiHost}?q=${latitude},${longitude}&format=${format}
        &key=${apiKey}&tp=${timePeriod}&num_of_days=${numsOfDay}
        &fx24=${forecastIn24Hour}&includelocation=${includeLocation}
        &mca=${monthlyCalculation}&fx=${forecast}&cc=${currentCondition}
        &showmap=${showMapUrl}`
    });
    const json = JSON.parse(data);
    let temp = Math.round(
      parseInt(json['data'].current_condition[0]['temp_C'])
    );

    response.body.temperature = temp;
    response.body.temperaturePercentage = Math.round((temp * 100) / 60);
  } catch (error) {
    console.log('Thermometer error message: ', JSON.stringify(error.message));
    response.status = 500;
  } finally {
    console.log(response);
    return response;
  }
};
